::: jaxspec.fit.BayesianModel
    options:
      show_root_heading: true
      show_root_full_path: false
      show_root_toc_entry: true
      heading_level: 3

## Fitter classes

::: jaxspec.fit.MCMCFitter
    options:
      show_root_heading: true
      show_root_full_path: false
      show_root_toc_entry: true
      heading_level: 3
